@@ -67,3 +67,7 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend): # pylint: d
         blob = self.get_blob_client(path)
         with open(src, 'rb') as f:
             blob.upload_blob(f)
+
+    def unlink(self, path):
+        """Remove a path."""
+        raise NotImplementedError
