@@ -76,6 +76,10 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """Returns the absolute path in the storage of `path`."""
         return os.path.join(self.base_path or '', *components)
 
+    def unlink(self, path):
+        """Remove a path."""
+        raise NotImplementedError("Subclasses must override this method.")
+
 
 class RemoteStorageBackendMixin: # pylint: disable=R0903
     """Overrides :class:`BaseStorageBackend` methods for use with remote
