@@ -55,3 +55,8 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend):
         """Copies local absolute path `src` to remote `path`."""
         blob = self.bucket.blob(self.storage_path(path))
         blob.upload_from_filename(src)
+
+    def unlink(self, path):
+        """Remove a path."""
+        self.bucket.delete_blobs(
+            blobs=list(self.bucket.list_blobs(prefix=self.storage_path(path))))
